# -*- coding: utf-8 -*-

# Description: Tests for the HCControl  module
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2011 Bundesamt fur Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import unittest
import os
import os.path

from mapwoc.lib.hccontrol import HCControl

class TestMappingFromFile(unittest.TestCase):
    def setUp(self):
        hcfilecontent_wo_shortcuts = """
[hc]
name=Lenny base, Konqueror 3.5.9
description=Debian Lenny 5.0.8 (base)
hcsid=lenny_konqueror_base
max_parallel=-1
controllable=true
active_browser=cpe:/a:konqueror:konqueror:3.5.9
os=cpe:/o:debian:debian_linux:5.0
installed_software=cpe:/o:debian:debian_linux:5.0

[control]
type=kvm
image_master=/usr/share/images/lenny-master.img
image_file=/usr/share/images/lenny_konqueror_base.ovl
image_snapshot=/usr/share/images/lenny_konqueror_base.snapshot
image_memory=128

[network]
own_ip=10.0.0.4
dns_ip=10.0.2.3
gateway_ip=10.0.0.1
proxy_ip=
homepage=http://10.0.0.1/lenny_konqueror_base
"""

        shortcuts = """
[keyboard-shortcuts]
homepage=alt-8
"""
        if not os.path.isdir("tests/tmp"):
            os.mkdir("tests/tmp")
        with open(os.path.join("tests/tmp", "lenny_iceweasel_base"),"w") as fname:
            fname.write(hcfilecontent_wo_shortcuts)
        with open(os.path.join("tests/tmp", "lenny_iceweasel_short"),"w") as fname:
            fname.write(hcfilecontent_wo_shortcuts.replace('base', 'short') + shortcuts)

    def test_regularhc(self):
        hc = HCControl(os.path.join("tests/tmp/lenny_iceweasel_base"))

        self.assertEqual(hc.name, "Lenny base, Konqueror 3.5.9", "Name-Value does not match.")
        self.assertEqual(hc.description, "Debian Lenny 5.0.8 (base)", "Description-Value does not match.")
        self.assertEqual(hc.image_file, "/usr/share/images/lenny_konqueror_base.ovl", "Image-filename-Value does not match.")
        self.assertEqual(hc.image_snapshot, "/usr/share/images/lenny_konqueror_base.snapshot", "Snapshot-Value does not match.")
        self.assertEqual(hc.image_memory, 128, "Memory-Value does not match.")
        self.assertEqual(hc.SHORTCUT_HOMEPAGE, "alt-home", "HP-shortcut-Value does not match.")

    def test_hc_w_shortcuts(self):
        hc = HCControl(os.path.join("tests/tmp/lenny_iceweasel_short"))

        self.assertEqual(hc.name, "Lenny short, Konqueror 3.5.9", "Name-Value does not match.")
        self.assertEqual(hc.description, "Debian Lenny 5.0.8 (short)", "Description-Value does not match.")
        self.assertEqual(hc.image_file, "/usr/share/images/lenny_konqueror_short.ovl", "Image-filename-Value does not match.")
        self.assertEqual(hc.image_snapshot, "/usr/share/images/lenny_konqueror_short.snapshot", "Snapshot-Value does not match.")
        self.assertEqual(hc.image_memory, 128, "Memory-Value does not match.")
        self.assertEqual(hc.SHORTCUT_HOMEPAGE, "alt-8", "HP-shortcut-Value does not match.")

    def tearDown(self):
        for base in ('lenny_iceweasel_base', 'lenny_iceweasel_short'):
            os.remove(os.path.join('tests/tmp', base))

